/*
 * Programming in Java, Jacobs University, 2015
 *
 * This file demonstrates the usage maps. It demonstrates different
 * ways to iterate over a map (a collection of key/value pairs).
 */

import java.util.Map;
import java.util.HashMap;
import java.util.TreeMap;

class M
{

    public static void iterateKeySet(Map<String, Integer> m)
    {
	// Iterate over the set of keys and then fetch the values.
	
	for (String s: m.keySet()) {
	    System.out.println(s + ":\t" + m.get(s));
	}
	System.out.println();
    }

    public static void iterateEntrySet(Map<String, Integer> m)
    {
	// Map.Entry is a nested class representing a key/value pair,
	// iterate over the set of key/value pair entries. This tends
	// to be faster than iterating over the key set.
	
	for (Map.Entry<String, Integer> entry: m.entrySet()) {
	    System.out.println(entry.getKey() + ":\t" + entry.getValue());
	}
	System.out.println();
    }

    public static void iterateLambdaExpresion(Map<String, Integer> m)
    {
	// Starting with java 1.8 we have lambda expressions....
	
	m.forEach((k,v) -> System.out.println(k + ":\t" + v));
	System.out.println();
    }

    public static void main(String[] args)
    {
	Map<String, Integer> m = new HashMap<String, Integer>();

	m.put("James", new Integer(42));
	m.put("Mary", new Integer(24));
	m.put("Anna", new Integer(41));

	iterateKeySet(m);
	iterateEntrySet(m);
	iterateLambdaExpresion(m);

	Map<String, Integer> sm = new TreeMap<String, Integer>(m);
	iterateLambdaExpresion(sm);

	for (String s: args) {
	    if (m.containsKey(s)) {
		System.out.println("Found " + s + " with id " + m.get(s));
	    }
	}

    }
}
